# penguin_analyst_aviv

This project can analyze your penguins

##Usage
```python
import penguin_analyst_aviv
df = penguin_analyst_aviv.get_penguins()
print(penguin_analyst_aviv.count_penguins()) # 344
print(penguin_analyst_aviv.islands()) # ['Torgersen','Dream','Biscoe']
```

## How to install
```python
pip install penguin_analyst_aviv
```